@@ -1,2 +1,3 @@
 from mysql2postgresql.connection_database import mysql2postgresql
-__all__ = ['mysql2postgresql']
+
+__all__ = ["mysql2postgresql"]
